@@ -297,7 +297,7 @@ class Device(Events):
 
     def grab_image_to_base64(self, x: int, y: int, width: int, height: int, rotation: int = 0, scale: float = 1) -> str:
         """
-        或去指定位置、大小及状态的范围截图。\n
+        获取指定位置、大小及状态的范围截图。\n
         :param x: 范围旋转缩放前的横坐标
         :param y: 范围旋转缩放前的纵坐标
         :param width: 范围旋转缩放前的宽度
